.. image:: https://github.com/ADemkin/di3/actions/workflows/ci.yml/badge.svg
   :target: https://github.com/ADemkin/di3/actions/workflows/ci.yml
   :alt: CI Status

.. image:: https://img.shields.io/badge/linter-ruff-black
   :target: https://github.com/astral-sh/ruff
   :alt: Ruff

.. image:: https://img.shields.io/badge/type--checker-mypy-blue
   :target: https://mypy-lang.org/
   :alt: Mypy

.. image:: https://img.shields.io/badge/python-3.10%20|%203.11%20|%203.12%20|%203.13%20|%203.14-green
   :alt: Supported Python Versions

Di3
===

Dependency Injection tree builder
